package com.upyun.screencapture.ui;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.media.projection.MediaProjection;
import android.media.projection.MediaProjectionManager;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.RadioGroup;

import com.upyun.screencapture.R;
import com.upyun.screencapturecore.CaptureEngine;
import com.upyun.screencapturecore.config.CaptureConfig;

public class MainActivity extends Activity implements View.OnClickListener {
    private static final String TAG = "MainActivity";
    private Button mBtnRecord = null;
    private Button mBtnCamera = null;
    private boolean mIsRecording = false;
    private boolean isCameraOn = false;
    private MediaProjectionManager mMediaProjectionManager = null;
    private MediaProjection mMediaProjection = null;
    private static final int REQUEST_MEDIA_PROJECTION = 1001;
    private String mOutputPath = "rtmp://testlivesdk.v0.upaiyun.com/live/upyunabcd";
    private int mBitrate = 1000000;
    private CaptureEngine mEngine;
    private CaptureConfig mConfig;
    private CaptureConfig.PushMode mPushMode;
    private RadioGroup mRadioGroup;
    private CaptureConfig.VideoResolution mVideoResolution;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mBtnRecord = (Button) findViewById(R.id.record);
        mBtnRecord.setOnClickListener(this);
        mBtnCamera = (Button) findViewById(R.id.camera);
        mBtnCamera.setOnClickListener(this);
        mRadioGroup = (RadioGroup) findViewById(R.id.rg_mode);
        mRadioGroup.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup group, int checkedId) {
                if (checkedId == R.id.horizontal_mode) {
                    mPushMode = CaptureConfig.PushMode.PUSH_MODE_HORIZONTAL;
                }
                else if (checkedId == R.id.portrait_mode) {
                    mPushMode = CaptureConfig.PushMode.PUSH_MODE_PORTRAIT;
                }
            }
        });

        //default
        mPushMode = CaptureConfig.PushMode.PUSH_MODE_PORTRAIT;
        mVideoResolution = CaptureConfig.VideoResolution.VIDEO_RESOLUTION_TYPE_540_960;

        mMediaProjectionManager = (MediaProjectionManager) getSystemService(Context.MEDIA_PROJECTION_SERVICE);
    }

    @Override
    public void onClick(View v) {
        if (v.getId() == R.id.record) {
            if (!mIsRecording) {
                if (mMediaProjectionManager != null) {
                    mConfig = new CaptureConfig(this, mOutputPath, mBitrate, mVideoResolution, mPushMode);
                    mEngine = new CaptureEngine(mConfig);
                    startActivityForResult(mMediaProjectionManager.createScreenCaptureIntent(), REQUEST_MEDIA_PROJECTION);
                }
            } else {
                mEngine.stop();
                mIsRecording = false;
            }
        } else if (v.getId() == R.id.camera) {
            if (!isCameraOn) {
                if (mEngine != null) {
                    isCameraOn = true;
                    mEngine.setCameraEnable(isCameraOn);
                }
            } else {
                if (mEngine != null) {
                    isCameraOn = false;
                    mEngine.setCameraEnable(isCameraOn);
                }
            }
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);

        if (requestCode == REQUEST_MEDIA_PROJECTION && resultCode == RESULT_OK) {
            mMediaProjection = mMediaProjectionManager.getMediaProjection(resultCode, data);
            if (mMediaProjection == null) {
                Log.e(TAG, "media projection is null");
                return;
            }

            mEngine.start(mMediaProjection);
            mIsRecording = true;
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();

        if (mIsRecording) {
            mEngine.stop();
            mIsRecording = false;
            isCameraOn = false;
        }
    }
}
